@@ -3,7 +3,7 @@ Preprocessing = c("histogram", "kernel density estimation", "k-nearest neighbour
 Criterion = c("AIC", "AIC3", "AIC4", "AICc", "BIC", "CAIC", "HQC", "MDL2", "MDL5", "AWE", "CLC", "ICL", "ICL-BIC", "PC", "D", "SSE"),
 Variables = c("continuous", "discrete"),
 pdf = c("normal", "lognormal", "Weibull", "binomial", "Poisson", "Dirac", "gamma", "uniform", "vonMises", "Gumbel"),
-pdf.nargs = c(2, 2, 2, 2, 1, 1, 2, 2, 2, 2),
+pdf.nargs = c(2, 2, 2, 2, 1, 1, 2, 2, 2, 3),
 pdf.Variables = c("continuous", "continuous", "continuous", "discrete", "discrete", "discrete", "continuous", "continuous", "continuous", "continuous"),
 Restraints = c("rigid", "loose"),
 ### Panic Branislav.
@@ -14,7 +14,7 @@ EMAcceleration = c("fixed", "line", "golden")),
 .Names = c("Preprocessing", "Criterion", "Variables", "pdf", "pdf.nargs", "pdf.Variables", "Restraints", "EMStrategy", "EMVariant", "EMAcceleration"))
 
 .rebmix.plot <- structure(list(
-what = c("pdf", "marginal pdf", "IC", "logL", "D", "marginal cdf", "K")),
+what = c("pdf", "marginal pdf", "IC", "logL", "D", "marginal cdf", "K", "cdf")),
 .Names = c("what"))
 
 .rebmix.boot <- structure(list(
@@ -25,6 +25,10 @@ Bootstrap = c("parametric", "nonparametric")),
 Rule = c("Sturges", "Log10", "RootN", "Knuth equal", "Knuth unequal")),
 .Names = c("Rule"))
 
+.rclrmix <- structure(list(
+Rule = c("Entropy", "Demp")),
+.Names = c("Rule"))
+
 
 
 
