@@ -124,12 +124,7 @@ function(x,
           hadj = 0.5,
           padj = 1.0)
 
-        if (.Device == "tikz output") {
-          text <- paste("$y_{", i, "}$", "$\\; - \\;$", "$y_{", j, "}$", sep = "")
-        }
-        else {
-          text <- bquote(y[.(i)] - y[.(j)])
-        }
+        text <- bquote(y[.(i)] - y[.(j)])
 
         mtext(text = text,
           side = 1,
@@ -203,12 +198,7 @@ function(x,
       hadj = 0.5,
       padj = 1.0)
 
-    if (.Device == "tikz output") {
-      text <- paste("$y_{1}$", "$\\; - \\;$", "$Z_{t}(y_{1})$", sep = "")
-    }
-    else {
-      text <- bquote(y[1] - Z[t](y[1]))
-    }
+    text <- bquote(y[1] - Z[t](y[1]))
 
     mtext(text = text,
       side = 1,
@@ -374,12 +364,7 @@ function(x,
           hadj = 0.5,
           padj = 1.0)
 
-        if (.Device == "tikz output") {
-          text <- paste("$y_{", i, "}$", "$\\; - \\;$", "$y_{", j, "}$", sep = "")
-        }
-        else {
-          text <- bquote(y[.(i)] - y[.(j)])
-        }
+        text <- bquote(y[.(i)] - y[.(j)])
 
         mtext(text = text,
           side = 1,
@@ -453,12 +438,7 @@ function(x,
       hadj = 0.5,
       padj = 1.0)
 
-    if (.Device == "tikz output") {
-      text <- paste("$y_{1}$", "$\\; - \\;$", "$Z_{t}(y_{1})$", sep = "")
-    }
-    else {
-      text <- bquote(y[1] - Z[t](y[1]))
-    }
+    text <- bquote(y[1] - Z[t](y[1]))
 
     mtext(text = text,
       side = 1,
