@@ -1833,6 +1833,7 @@ void RCombineComponentsMVNORM(INT    *c,            // Number of components.
                               INT    *T,            // To components.
                               double *EN,           // Entropy.
                               double *ED,           // Entropy decrease.
+                              double *PSS,          // Pairwise similarity scores.
                               INT    *Error)        // Error code.
 {
     Rebmvnorm *rebmvnorm = NULL;
@@ -1893,7 +1894,8 @@ void RCombineComponentsMVNORM(INT    *c,            // Number of components.
             F,
             T,
             EN,
-            ED);
+            ED,
+            PSS);
 
         if (*Error) goto E0;
     }
@@ -1906,7 +1908,8 @@ void RCombineComponentsMVNORM(INT    *c,            // Number of components.
             F,
             T,
             EN,
-            ED);
+            ED,
+            PSS);
 
         if (*Error) goto E0;
     }
