@@ -33,7 +33,7 @@ extern void RInformationCriterionHMIX(void *, void *, void *, void *, void *, vo
 extern void RInformationCriterionKMIX(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void RInformationCriterionMIX(void *, void *, void *, void *, void *, void *,  void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
-extern void RCombineComponentsMIX(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void RCombineComponentsMIX(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
 /// Panic Branislav
 extern void REMMIX(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,
@@ -61,7 +61,7 @@ extern void RInformationCriterionHMVNORM(void *, void *, void *, void *, void *,
 extern void RInformationCriterionKMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void RInformationCriterionMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
-extern void RCombineComponentsMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void RCombineComponentsMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
 /// Panic Branislav
 extern void REMMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,
@@ -83,6 +83,10 @@ extern void RMvtNormalPdf(void *, void *, void *, void *, void *, void *);
 extern void Rfhistogram(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void Rchistogram(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
+extern void RLabelMomentsXY(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void RLabelMomentsXYZ(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void RMergeLabels(void *, void *, void *, void *, void *, void *);
+
 static const R_CMethodDef CMethods[] = {
     {"RRNGMIX", (DL_FUNC) &RRNGMIX, 13},
     {"RREBMIX", (DL_FUNC) &RREBMIX, 55},
@@ -104,7 +108,7 @@ static const R_CMethodDef CMethods[] = {
     {"RInformationCriterionHMIX", (DL_FUNC) &RInformationCriterionHMIX, 23},
     {"RInformationCriterionKMIX", (DL_FUNC)&RInformationCriterionKMIX, 19},
     {"RInformationCriterionMIX", (DL_FUNC)&RInformationCriterionMIX, 18},
-    {"RCombineComponentsMIX", (DL_FUNC) &RCombineComponentsMIX, 17},
+    {"RCombineComponentsMIX", (DL_FUNC) &RCombineComponentsMIX, 18},
     {"RRNGMVNORM", (DL_FUNC) &RRNGMVNORM, 12},
     {"RREBMVNORM", (DL_FUNC) &RREBMVNORM, 54},
     {"RCLSMVNORM", (DL_FUNC) &RCLSMVNORM, 13},
@@ -118,7 +122,7 @@ static const R_CMethodDef CMethods[] = {
     {"RInformationCriterionHMVNORM", (DL_FUNC) &RInformationCriterionHMVNORM, 20},
     {"RInformationCriterionKMVNORM", (DL_FUNC)&RInformationCriterionKMVNORM, 16},
     {"RInformationCriterionMVNORM", (DL_FUNC)&RInformationCriterionMVNORM, 15},
-    {"RCombineComponentsMVNORM", (DL_FUNC) &RCombineComponentsMVNORM, 17},
+    {"RCombineComponentsMVNORM", (DL_FUNC) &RCombineComponentsMVNORM, 18},
     {"RvonMisesPdf", (DL_FUNC) &RvonMisesPdf, 5},
     {"RvonMisesCdf", (DL_FUNC) &RvonMisesCdf, 5},
     {"RGumbelPdf", (DL_FUNC) &RGumbelPdf, 6},
@@ -133,6 +137,9 @@ static const R_CMethodDef CMethods[] = {
 /// End
     {"Rfhistogram", (DL_FUNC)&Rfhistogram, 10},
     {"Rchistogram", (DL_FUNC)&Rchistogram, 10},
+    {"RLabelMomentsXY", (DL_FUNC)&RLabelMomentsXY, 11},
+    {"RLabelMomentsXYZ", (DL_FUNC)&RLabelMomentsXYZ, 13},
+    {"RMergeLabels", (DL_FUNC)&RMergeLabels, 6},
     {NULL, NULL, 0}
 };
 
