@@ -160,9 +160,9 @@ public:
     INT InformationCriterionKDE(FLOAT logV, FLOAT **Y, INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *IC, FLOAT *logL, INT *M, FLOAT *D);
     INT InformationCriterionH(FLOAT logV, INT k, FLOAT **Y, INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *IC, FLOAT *logL, INT *M, FLOAT *D);
     INT InformationCriterion(INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *IC, FLOAT *logL, INT *M, FLOAT *D);
-    INT CombineComponentsEntropy(INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *tau, INT *F, INT *T, FLOAT *EN, FLOAT *ED);
+    INT CombineComponentsEntropy(INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *tau, INT *F, INT *T, FLOAT *EN, FLOAT *ED, FLOAT *PSS);
 /// Panic Branislav
-    INT CombineComponentsDemp(INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *tau, INT *F, INT *T, FLOAT *EN, FLOAT *ED);
+    INT CombineComponentsDemp(INT c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *tau, INT *F, INT *T, FLOAT *EN, FLOAT *ED, FLOAT *PSS);
 /// End
     INT REBMIX();
     INT Set(char  **Preprocessing,    // Preprocessing type.
